==> root-6.16.00-5-x86_64.pkg.tar.xz: etc/root/dictpch/allLinkDefs.h <==
#include "etc/dictpch/core/multiproc/inc/LinkDef.h"
#include "etc/dictpch/core/rint/inc/LinkDef.h"
#include "etc/dictpch/core/thread/inc/LinkDef.h"
#include "etc/dictpch/core/imt/inc/LinkDef.h"
#include "etc/dictpch/core/base/inc/LinkDef.h"
#include "etc/dictpch/core/base/inc/LinkDef1.h"
#include "etc/dictpch/core/base/inc/LinkDef2.h"
#include "etc/dictpch/core/base/inc/LinkDef3.h"
#include "etc/dictpch/math/mathcore/inc/LinkDef.h"
#include "etc/dictpch/math/mathcore/inc/LinkDef1.h"
#include "etc/dictpch/math/mathcore/inc/LinkDef2.h"
#include "etc/dictpch/math/mathcore/inc/LinkDef3.h"
#include "etc/dictpch/math/mathcore/inc/LinkDef_Func.h"
#include "etc/dictpch/math/mathmore/inc/Math/LinkDef.h"
#include "etc/dictpch/math/mathmore/inc/Math/LinkDef_Func.h"
#include "etc/dictpch/math/mathmore/inc/Math/LinkDef_RootFinding.h"
#include "etc/dictpch/math/matrix/inc/LinkDef.h"
#include "etc/dictpch/math/minuit/inc/LinkDef.h"
#include "etc/dictpch/math/minuit2/inc/LinkDef.h"
#include "etc/dictpch/math/physics/inc/LinkDef.h"
#include "etc/dictpch/math/smatrix/inc/LinkDef.h"
#include "etc/dictpch/math/smatrix/inc/LinkDefAll.h"
#include "etc/dictpch/math/smatrix/inc/LinkDefD32.h"
#include "etc/dictpch/math/smatrix/inc/LinkDef.h"
#include "etc/dictpch/math/smatrix/inc/LinkDefAll.h"
#include "etc/dictpch/math/smatrix/inc/LinkDefD32.h"
#include "etc/dictpch/math/genvector/inc/Math/LinkDef_GenVector.h"
#include "etc/dictpch/math/genvector/inc/Math/LinkDef_GenVector2.h"
#include "etc/dictpch/math/genvector/inc/Math/LinkDef_GenVector32.h"
#include "etc/dictpch/math/genvector/inc/Math/LinkDef_GenVectorAll.h"
#include "etc/dictpch/math/genvector/inc/Math/LinkDef_GenVector.h"
#include "etc/dictpch/math/genvector/inc/Math/LinkDef_GenVector2.h"
#include "etc/dictpch/math/genvector/inc/Math/LinkDef_GenVector32.h"
#include "etc/dictpch/math/genvector/inc/Math/LinkDef_GenVectorAll.h"
#include "etc/dictpch/math/genetic/inc/LinkDef.h"
#include "etc/dictpch/math/vecops/inc/LinkDef.h"
#include "etc/dictpch/hist/hist/inc/LinkDef.h"
#include "etc/dictpch/hist/histdraw/inc/LinkDef.h"
#include "etc/dictpch/hist/histpainter/inc/LinkDef.h"
#include "etc/dictpch/hist/spectrum/inc/LinkDef.h"
#include "etc/dictpch/hist/spectrumpainter/inc/LinkDef.h"
#include "etc/dictpch/hist/unfold/inc/LinkDef.h"
#include "etc/dictpch/hist/hbook/inc/LinkDef.h"
#include "etc/dictpch/tree/tree/inc/LinkDef.h"
#include "etc/dictpch/tree/treeplayer/inc/LinkDef.h"
#include "etc/dictpch/tree/treeviewer/inc/LinkDef.h"
#include "etc/dictpch/tree/dataframe/inc/LinkDef.h"
#include "etc/dictpch/io/io/inc/LinkDef.h"
#include "etc/dictpch/net/net/inc/LinkDef.h"
#include "etc/dictpch/net/netx/inc/LinkDef.h"
#include "etc/dictpch/net/netxng/inc/LinkDef.h"
#include "etc/dictpch/graf2d/primitives/inc/LinkDef.h"
#include "etc/dictpch/graf2d/gpadv7/inc/LinkDef.h"
#include "etc/dictpch/graf2d/gpad/inc/LinkDef.h"
#include "etc/dictpch/graf2d/graf/inc/LinkDef.h"
#include "etc/dictpch/graf2d/postscript/inc/LinkDef.h"
#include "etc/dictpch/graf2d/x11/inc/LinkDef.h"
#include "etc/dictpch/graf2d/x11ttf/inc/LinkDef.h"
#include "etc/dictpch/graf2d/asimage/inc/LinkDef.h"
#include "etc/dictpch/graf2d/asimage/inc/LinkDefGui.h"
#include "etc/dictpch/graf2d/asimage/inc/LinkDef.h"
#include "etc/dictpch/graf2d/asimage/inc/LinkDefGui.h"
#include "etc/dictpch/graf2d/fitsio/inc/LinkDef.h"
#include "etc/dictpch/graf3d/g3d/inc/LinkDef.h"
#include "etc/dictpch/graf3d/gl/inc/LinkDef.h"
#include "etc/dictpch/gui/gui/inc/LinkDef.h"
#include "etc/dictpch/gui/gui/inc/LinkDef1.h"
#include "etc/dictpch/gui/gui/inc/LinkDef2.h"
#include "etc/dictpch/gui/gui/inc/LinkDef3.h"
#include "etc/dictpch/gui/fitpanel/inc/LinkDef.h"
#include "etc/dictpch/gui/fitpanelv7/inc/LinkDef.h"
#include "etc/dictpch/bindings/pyroot/inc/LinkDef.h"
#include "etc/dictpch/tmva/tmva/inc/LinkDef.h"
#include "etc/dictpch/tmva/tmva/inc/LinkDef1.h"
#include "etc/dictpch/tmva/tmva/inc/LinkDef2.h"
#include "etc/dictpch/tmva/tmva/inc/LinkDef3.h"
#include "etc/dictpch/tmva/tmva/inc/LinkDef4.h"
#include "etc/dictpch/tmva/tmva/inc/LinkDef5.h"
#include "etc/dictpch/tmva/tmvagui/inc/LinkDef.h"
#include "etc/dictpch/tmva/pymva/inc/LinkDef.h"
#include "etc/dictpch/roofit/roofitcore/inc/LinkDef.h"
#include "etc/dictpch/roofit/roofitcore/inc/LinkDef1.h"
#include "etc/dictpch/roofit/roofitcore/inc/LinkDef2.h"
#include "etc/dictpch/roofit/roofitcore/inc/LinkDef3.h"
#include "etc/dictpch/roofit/roofitcore/inc/LinkDef4.h"
#include "etc/dictpch/roofit/roofitcore/inc/RooFitCore_LinkDef.h"
#include "etc/dictpch/roofit/roofit/inc/LinkDef1.h"
#include "etc/dictpch/roofit/roostats/inc/LinkDef.h"
#include "etc/dictpch/roofit/histfactory/inc/LinkDef.h"

==> root-6.18.00-3-x86_64.pkg.tar.xz: etc/root/dictpch/allLinkDefs.h <==
#include "etc/dictpch/roofit/histfactory/inc/LinkDef.h"
#include "etc/dictpch/roofit/roostats/inc/LinkDef.h"
#include "etc/dictpch/roofit/roofit/inc/LinkDef1.h"
#include "etc/dictpch/roofit/roofitcore/inc/RooFitCore_LinkDef.h"
#include "etc/dictpch/roofit/roofitcore/inc/LinkDef4.h"
#include "etc/dictpch/roofit/roofitcore/inc/LinkDef3.h"
#include "etc/dictpch/roofit/roofitcore/inc/LinkDef2.h"
#include "etc/dictpch/roofit/roofitcore/inc/LinkDef1.h"
#include "etc/dictpch/roofit/roofitcore/inc/LinkDef.h"
#include "etc/dictpch/tmva/pymva/inc/LinkDef.h"
#include "etc/dictpch/tmva/tmvagui/inc/LinkDef.h"
#include "etc/dictpch/tmva/tmva/inc/LinkDef5.h"
#include "etc/dictpch/tmva/tmva/inc/LinkDef4.h"
#include "etc/dictpch/tmva/tmva/inc/LinkDef3.h"
#include "etc/dictpch/tmva/tmva/inc/LinkDef2.h"
#include "etc/dictpch/tmva/tmva/inc/LinkDef1.h"
#include "etc/dictpch/tmva/tmva/inc/LinkDef.h"
#include "etc/dictpch/bindings/pyroot/inc/LinkDef.h"
#include "etc/dictpch/gui/fitpanelv7/inc/LinkDef.h"
#include "etc/dictpch/gui/fitpanel/inc/LinkDef.h"
#include "etc/dictpch/gui/gui/inc/LinkDef3.h"
#include "etc/dictpch/gui/gui/inc/LinkDef2.h"
#include "etc/dictpch/gui/gui/inc/LinkDef1.h"
#include "etc/dictpch/gui/gui/inc/LinkDef.h"
#include "etc/dictpch/graf3d/gl/inc/LinkDef.h"
#include "etc/dictpch/graf3d/g3d/inc/LinkDef.h"
#include "etc/dictpch/graf2d/fitsio/inc/LinkDef.h"
#include "etc/dictpch/graf2d/gviz/inc/LinkDef.h"
#include "etc/dictpch/graf2d/asimage/inc/LinkDefGui.h"
#include "etc/dictpch/graf2d/asimage/inc/LinkDef.h"
#include "etc/dictpch/graf2d/asimage/inc/LinkDefGui.h"
#include "etc/dictpch/graf2d/asimage/inc/LinkDef.h"
#include "etc/dictpch/graf2d/x11ttf/inc/LinkDef.h"
#include "etc/dictpch/graf2d/x11/inc/LinkDef.h"
#include "etc/dictpch/graf2d/postscript/inc/LinkDef.h"
#include "etc/dictpch/graf2d/graf/inc/LinkDef.h"
#include "etc/dictpch/graf2d/gpad/inc/LinkDef.h"
#include "etc/dictpch/graf2d/gpadv7/inc/LinkDef.h"
#include "etc/dictpch/graf2d/primitives/inc/LinkDef.h"
#include "etc/dictpch/net/netxng/inc/LinkDef.h"
#include "etc/dictpch/net/netx/inc/LinkDef.h"
#include "etc/dictpch/net/net/inc/LinkDef.h"
#include "etc/dictpch/io/io/inc/LinkDef.h"
#include "etc/dictpch/tree/ntuple/inc/LinkDef.h"
#include "etc/dictpch/tree/dataframe/inc/LinkDef.h"
#include "etc/dictpch/tree/treeviewer/inc/LinkDef.h"
#include "etc/dictpch/tree/treeplayer/inc/LinkDef.h"
#include "etc/dictpch/tree/tree/inc/LinkDef.h"
#include "etc/dictpch/hist/hbook/inc/LinkDef.h"
#include "etc/dictpch/hist/unfold/inc/LinkDef.h"
#include "etc/dictpch/hist/spectrumpainter/inc/LinkDef.h"
#include "etc/dictpch/hist/spectrum/inc/LinkDef.h"
#include "etc/dictpch/hist/histpainter/inc/LinkDef.h"
#include "etc/dictpch/hist/histdraw/inc/LinkDef.h"
#include "etc/dictpch/hist/hist/inc/LinkDef.h"
#include "etc/dictpch/math/vecops/inc/LinkDef.h"
#include "etc/dictpch/math/genetic/inc/LinkDef.h"
#include "etc/dictpch/math/genvector/inc/Math/LinkDef_GenVectorAll.h"
#include "etc/dictpch/math/genvector/inc/Math/LinkDef_GenVector32.h"
#include "etc/dictpch/math/genvector/inc/Math/LinkDef_GenVector2.h"
#include "etc/dictpch/math/genvector/inc/Math/LinkDef_GenVector.h"
#include "etc/dictpch/math/genvector/inc/Math/LinkDef_GenVectorAll.h"
#include "etc/dictpch/math/genvector/inc/Math/LinkDef_GenVector32.h"
#include "etc/dictpch/math/genvector/inc/Math/LinkDef_GenVector2.h"
#include "etc/dictpch/math/genvector/inc/Math/LinkDef_GenVector.h"
#include "etc/dictpch/math/smatrix/inc/LinkDefD32.h"
#include "etc/dictpch/math/smatrix/inc/LinkDefAll.h"
#include "etc/dictpch/math/smatrix/inc/LinkDef.h"
#include "etc/dictpch/math/smatrix/inc/LinkDefD32.h"
#include "etc/dictpch/math/smatrix/inc/LinkDefAll.h"
#include "etc/dictpch/math/smatrix/inc/LinkDef.h"
#include "etc/dictpch/math/physics/inc/LinkDef.h"
#include "etc/dictpch/math/minuit2/inc/LinkDef.h"
#include "etc/dictpch/math/minuit/inc/LinkDef.h"
#include "etc/dictpch/math/matrix/inc/LinkDef.h"
#include "etc/dictpch/math/mathmore/inc/Math/LinkDef_RootFinding.h"
#include "etc/dictpch/math/mathmore/inc/Math/LinkDef_Func.h"
#include "etc/dictpch/math/mathmore/inc/Math/LinkDef.h"
#include "etc/dictpch/math/mathcore/inc/LinkDef_Func.h"
#include "etc/dictpch/math/mathcore/inc/LinkDef3.h"
#include "etc/dictpch/math/mathcore/inc/LinkDef2.h"
#include "etc/dictpch/math/mathcore/inc/LinkDef1.h"
#include "etc/dictpch/math/mathcore/inc/LinkDef.h"
#include "etc/dictpch/core/imt/inc/LinkDef.h"
#include "etc/dictpch/core/thread/inc/LinkDef.h"
#include "etc/dictpch/core/rint/inc/LinkDef.h"
#include "etc/dictpch/core/multiproc/inc/LinkDef.h"
#include "etc/dictpch/core/winnt/inc/LinkDef.h"
#include "etc/dictpch/core/unix/inc/LinkDef.h"
#include "etc/dictpch/core/thread/inc/LinkDef.h"
#include "etc/dictpch/core/rint/inc/LinkDef.h"
#include "etc/dictpch/core/multiproc/inc/LinkDef.h"
#include "etc/dictpch/core/meta/inc/LinkDef.h"
#include "etc/dictpch/core/macosx/inc/LinkDef.h"
#include "etc/dictpch/core/imt/inc/LinkDef.h"
#include "etc/dictpch/core/cont/inc/LinkDef.h"
#include "etc/dictpch/core/base/inc/LinkDef3.h"
#include "etc/dictpch/core/base/inc/LinkDef2.h"
#include "etc/dictpch/core/base/inc/LinkDef1.h"
#include "etc/dictpch/core/base/inc/LinkDef.h"
